package com.spider.auth.service.impl;

import com.alibaba.nacos.common.utils.UuidUtils;
import com.spider.auth.service.AuthService;
import com.spider.common.constant.JwtConstants;
import com.spider.common.constant.TokenConstants;
import com.spider.common.domain.User;
import com.spider.common.domain.request.LoginReq;
import com.spider.common.domain.response.JwtResponse;
import com.spider.common.remote.UserRemote;
import com.spider.common.result.Result;
import com.spider.common.utils.JsonUtil;
import com.spider.common.utils.JwtUtils;
import com.spider.common.utils.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.redis.core.RedisTemplate;
import org.springframework.stereotype.Service;

import javax.servlet.http.HttpServletRequest;
import java.util.HashMap;
import java.util.Objects;
import java.util.concurrent.TimeUnit;

/**
 * 📝 TODO
 * 🕟 2024/1/19 9:55
 * 👦 Lxj
 */
@Service
public class AuthServiceImpl implements AuthService {

    @Autowired
    private UserRemote userRemote;

    @Autowired
    private RedisTemplate<String,Object> redisTemplate;

    @Autowired
    private HttpServletRequest request;

    /**
     * 登录
     * @param loginReq
     * @return
     */
    @Override
    public Result<JwtResponse> login(LoginReq loginReq) {

        //判空
        if(StringUtils.isNull(loginReq)){
            return Result.error("请输入用户名密码");
        }

        //查询用户信息
        Result<User> userInfo = userRemote.info(loginReq.getUserAccount());

        User user = userInfo.getData();

        if(null == user){
            return Result.error(userInfo.getMsg());
        }

        return Result.success(this.createToken(user));
    }

    /**
     * 获取用户信息
     * @return
     */
    @Override
    public Result<String> info() {
        String userAccount = request.getHeader(JwtConstants.DETAILS_USERNAME);

        if(null == userAccount){
            return Result.error("获取用户信息异常");
        }

        return Result.success(userAccount);
    }

    /**
     * 生成token
     * @param user
     * @return
     */
    public JwtResponse createToken(User user){
        HashMap<String, Object> hashMap = new HashMap<>();

        String userKey = UuidUtils.generateUuid();
        hashMap.put(JwtConstants.USER_KEY,userKey);
        hashMap.put(JwtConstants.DETAILS_USER_ID,user.getUserId());
        hashMap.put(JwtConstants.DETAILS_USERNAME,user.getUserAccount());

        String token = JwtUtils.createToken(hashMap);

        redisTemplate.opsForValue().set(
                TokenConstants.LOGIN_TOKEN_KEY+userKey,
                JsonUtil.parseJSONObject(user),
                TokenConstants.EXPIRATION,
                TimeUnit.MINUTES
        );

        return JwtResponse.builder().token(token)
                .existTime(TokenConstants.EXPIRATION+""+TimeUnit.MINUTES)
                .build();

    }
}
