package com.spider.common.domain;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.Size;
import javax.validation.constraints.NotNull;

import java.io.Serializable;

import java.util.Date;

import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModelProperty;
import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;
import org.hibernate.validator.constraints.Length;
import org.springframework.format.annotation.DateTimeFormat;

/**
*
* @TableName t_car
*/
@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
public class Car implements Serializable {

    /**
    * 车辆ID
    */
//    @NotNull(message="[车辆ID]不能为空")
    @ApiModelProperty("车辆ID")
    private Integer carId;
    /**
     * 员工主键
     */
//    @NotNull(message="[员工主键]不能为空")
    @ApiModelProperty("员工主键")
    private Integer empId;
    /**
    * 车牌号
    */
    @Size(max= 40,message="编码长度不能超过40")
    @ApiModelProperty("车牌号")
    @Length(max= 40,message="编码长度不能超过40")
    @NotBlank(message = "车牌号不能为空")
    private String carCard;
    /**
    * 车辆型号
    */
    @Size(max= 40,message="编码长度不能超过40")
    @ApiModelProperty("车辆型号")
    @Length(max= 40,message="编码长度不能超过40")
    @NotBlank(message = "车辆型号不能为空")
    private String carModel;
    /**
    * 登记时间
    */
    @ApiModelProperty("登记时间")
    @JsonFormat(pattern = "yyyy-MM-dd HH:ss:mm",timezone = "GMT+8")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:ss:mm")
    private Date regTime;
    /**
    * 车辆位置
    */
    @Size(max= 100,message="编码长度不能超过100")
    @ApiModelProperty("车辆位置")
    @Length(max= 100,message="编码长度不能超过100")
    private String carPosition;
    /**
    * 类型 0:临时车辆 1:长期车辆
    */
    @ApiModelProperty("类型 0:临时车辆 1:长期车辆")
    private Integer carType;
    /**
    * 状态 0:有效 1:已失效
    */
    @ApiModelProperty("状态 0:有效 1:已失效")
    private Integer carState;
    /**
    * 进入校园次数
    */
    @ApiModelProperty("进入校园次数")
    private Integer carCount;
    /**
    * 最近一次进出校园时间
    */
    @ApiModelProperty("最近一次进出校园时间")
    @JsonFormat(pattern = "yyyy-MM-dd HH:ss:mm",timezone = "GMT+8")
    @DateTimeFormat(pattern = "yyyy-MM-dd HH:ss:mm")
    private Date latelyTime;



}
