package com.spider.system.controller;

import com.spider.common.domain.Car;
import com.spider.common.domain.request.CarReq;
import com.spider.common.domain.response.CarRes;
import com.spider.common.domain.response.EchoCarRes;
import com.spider.common.result.Result;
import com.spider.system.service.CarService;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.util.List;

/**
 * 📝 TODO
 * 🕟 2024/1/19 10:50
 * 👦 Lxj
 */
@RestController
@RequestMapping("/car")
@Log4j2
public class CarController {

    private final CarService carService;

    public CarController(CarService carService) {
        this.carService = carService;
    }

    @Autowired
    private HttpServletRequest request;

    /**
     * 获取车辆信息
     * @param carReq
     * @return
     */
    @PostMapping("/queryCar")
    public Result<List<CarRes>> queryCar(@RequestBody CarReq carReq){
        return  carService.getCarList(carReq);
    }

    /**
     * 取消登记
     * @return
     */
    @PostMapping("/cancelReg")
    public Result<String> cancelReg(@RequestBody String[] carIds ){
        log.info("功能描述: xx,请求URI：{},请求方式: {},请求参数: {}",
                request.getRequestURI(),request.getMethod(),carIds);

        return carService.updCarState(carIds);
    }

    /**
     * 登记
     * @return
     */
    @PostMapping("/sign")
    public Result<String> sign(@RequestBody @Validated Car car){
        return carService.saveCar(car);
    }

    /**
     * 获取车辆信息
     * @param carId
     * @return
     */
    @GetMapping("/redact")
    public Result<CarRes> redact(@RequestParam String carId){
        return carService.getCarResByCarId(carId);
    }

    /**
     * 更新数据
     * @return
     */
    @PostMapping("/renewal")
    public Result<String> renewal(@RequestBody @Validated Car car){
        return carService.renewal(car);
    }

    /**
     * 回显登记信息
     * @return
     */
    @GetMapping("/echoCar")
    public Result<EchoCarRes> echoCar(@RequestParam String carId){
        return carService.getEchoCarResByCarId(carId);
    }




}
