package com.spider.system.service.impl;

import com.spider.common.domain.Car;
import com.spider.common.domain.bo.CarBo;
import com.spider.common.domain.bo.EmpBo;
import com.spider.common.domain.request.CarReq;
import com.spider.common.domain.response.CarRes;
import com.spider.common.domain.response.EchoCarRes;
import com.spider.common.result.Result;
import com.spider.common.utils.MsgUtil;
import com.spider.common.utils.StringUtils;
import com.spider.system.mapper.CarMapper;
import com.spider.system.mapper.EmpMapper;
import com.spider.system.service.CarService;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 📝 TODO
 * 🕟 2024/1/19 10:50
 * 👦 Lxj
 */
@Service
@Log4j2
public class CarServiceImpl implements CarService {
    private final CarMapper carMapper;

    private final EmpMapper empMapper;

    public CarServiceImpl(CarMapper carMapper, EmpMapper empMapper) {
        this.carMapper = carMapper;

        this.empMapper = empMapper;
    }



    @Autowired
    private MsgUtil msgUtil;

    /**
     * 获取车辆
     * @param carReq
     * @return
     */
    @Override
    public Result<List<CarRes>> getCarList(CarReq carReq) {

        List<CarRes> cars = carMapper.selectCarList(carReq);

        if(StringUtils.isEmpty(cars)){
            return Result.error("获取车辆异常");
        }

        return Result.success(cars);
    }


    /**
     * 所选记录状态可以正确的更新为已失效
     * @param carIds
     * @return
     */
    @Override
    public Result<String> updCarState(String[] carIds) {

        int res = carMapper.updCarStateByCarId(carIds);

        if(res < 1){
            return Result.error("操作异常,请稍后");
        }

        //获取信息
        List<CarBo> carBos = carMapper.selectCarAndEmpByCarId(carIds);

        if(StringUtils.isEmpty(carBos)){
            return Result.error("短信发送异常");
        }

        //循环发短信
        carBos.forEach(carBo -> {
            String msg = msgUtil.sendMsg(
                    carBo.getMobile(),
                    "尊敬的" + carBo.getEmpName() + "你的车辆<" + carBo.getCarCard() + ">已取消登记成功"
            );
            log.info(msg);

            if(msg.contains("ok")){
                log.info("尊敬的" + carBo.getEmpName() + "你的车辆<" + carBo.getCarCard() + ">已取消登记成功");
            }else {
                log.error("尊敬的" + carBo.getEmpName() + "你的车辆<" + carBo.getCarCard() + ">取消登记失败");
            }
        });


        return Result.success();
    }

    /**
     * 登记车辆
     * @param car
     * @return
     */
    @Override
    public Result<String> saveCar(Car car) {

        int res = carMapper.insertCar(car);

        if(res < 1){
            return Result.error("登记异常,请稍后");
        }

        String empId = String.valueOf(car.getEmpId());

        EmpBo empBo = empMapper.selectEmpByEmpId(empId);

        String msg = msgUtil.sendMsg(
                empBo.getEmpMobile(),
                "尊敬的" + empBo.getEmpName() + "你的车辆<" + empBo.getEmpMobile() + ">已取消登记成功"
        );

        log.info(msg);

        if(msg.contains("ok")){
            log.info("尊敬的" + empBo.getEmpName() + "你的车辆<" + empBo.getEmpMobile() + ">已取消登记成功");
        }else {
            log.error("尊敬的" + empBo.getEmpName() + "你的车辆<" + empBo.getEmpMobile() + ">取消登记失败");
        }

        return Result.success();
    }

    /**
     * 查询车辆信息
     * @param carId
     * @return
     */
    @Override
    public Result<CarRes> getCarResByCarId(String carId) {

        CarRes carRes = carMapper.selectCarByCarId(carId);

        if(StringUtils.isNull(carRes)){
            return Result.error("获取异常,请重试");
        }

        return Result.success(carRes);
    }

    /**
     * 更新数据
     * @param car
     * @return
     */
    @Override
    public Result<String> renewal(Car car) {

        int res = carMapper.updCarByCarId(car);

        if(res < 1){
            return Result.error("更新异常,请稍后");
        }

        return Result.success();
    }

    /**
     * 获取车辆
     * @param carId
     * @return
     */
    @Override
    public Result<EchoCarRes> getEchoCarResByCarId(String carId) {
        EchoCarRes echoCarRes = carMapper.selectEchoCarResByCarId(carId);

        if(StringUtils.isNull(echoCarRes)){
            return Result.error("获取异常,请重试");
        }

        return Result.success(echoCarRes);
    }
}
